@@ -3,7 +3,7 @@
 # dpkg-repack puts humpty-dumpty back together again.
 #
 # Copyright © 1996-2006 Joey Hess <joeyh@debian.org>
-# Copyright © 2012, 2014-2021 Guillem Jover <guillem@debian.org>
+# Copyright © 2012, 2014-2023 Guillem Jover <guillem@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -214,7 +214,7 @@ sub Install_Files {
         if ($line =~ /^(.*)\s+(\S+)\s+obsolete$/) {
             push @obsolete_conffiles, $1;
         } elsif ($line =~ /^(.*)\s+(\S+)\s+remove-on-upgrade$/) {
-            push @removing_conffiles, $1
+            push @removing_conffiles, $1;
         } elsif ($line =~ /^(.*)\s+(\S+)$/) {
             push @conffiles, $1;
         }
